PrintDocumentBlock class
One layout element inside a PrintDocument.
Constructors
-
PrintDocumentBlock({required String type, String? text, String? left, String? right, String? align, bool? bold, String? size, String? locale, List<
String> ? columns, List<List< ? rows, int? columnCount, String? layout, bool? boldFirstColumn, bool? boldHeader, String? value, int? lines, String? char})String> > -
const
-
PrintDocumentBlock.fromJson(Map<
String, dynamic> json) -
factory
Properties
- align → String?
-
final
- bold → bool?
-
final
- boldFirstColumn → bool?
-
final
- boldHeader → bool?
-
final
- char → String?
-
final
- columnCount → int?
-
final
-
columns
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → String?
-
final
- left → String?
-
final
- lines → int?
-
final
- locale → String?
-
final
- right → String?
-
final
-
rows
→ List<
List< ?String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → String?
-
final
- text → String?
-
final
- type → String
-
final
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited